DeserializationMessage class

"Root" level class for use in an isolate.

Constructors

DeserializationMessage({required String json, required String targetType, bool growable = false})
const

Properties

growable → bool
Whether to make deserialized lists or maps growable.
final
hashCode → int
The hash code for this object.
no setterinherited
json → String
The JSON value to deserialize.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetType → String
Target type to deserialize to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited