MattermostIntegrationActionsApi class

Properties

apiClient → MattermostApiClient
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openInteractiveDialog(MmOpenInteractiveDialogRequest mmOpenInteractiveDialogRequest) → Future<MmStatusOK?>
Open a dialog
openInteractiveDialogWithHttpInfo(MmOpenInteractiveDialogRequest mmOpenInteractiveDialogRequest) → Future<Response>
Open a dialog
submitInteractiveDialog(MmSubmitInteractiveDialogRequest mmSubmitInteractiveDialogRequest) → Future<MmStatusOK?>
Submit a dialog
submitInteractiveDialogWithHttpInfo(MmSubmitInteractiveDialogRequest mmSubmitInteractiveDialogRequest) → Future<Response>
Submit a dialog
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited