MattermostRootApi class

Constructors

MattermostRootApi(MattermostApiClient apiClient)

Properties

apiClient → MattermostApiClient
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

acknowledgeNotification() → Future<MmPushNotification?>
Acknowledge receiving of a notification
acknowledgeNotificationWithHttpInfo() → Future<Response>
Acknowledge receiving of a notification
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited