MattermostSharedChannelsApi class

Properties

apiClient → MattermostApiClient
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllSharedChannels(String teamId, {int? page, int? perPage}) → Future<List<MmSharedChannel>?>
Get all shared channels for team.
getAllSharedChannelsWithHttpInfo(String teamId, {int? page, int? perPage}) → Future<Response>
Get all shared channels for team.
getRemoteClusterInfo(String remoteId) → Future<MmRemoteClusterInfo?>
Get remote cluster info by ID for user.
getRemoteClusterInfoWithHttpInfo(String remoteId) → Future<Response>
Get remote cluster info by ID for user.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited