MattermostSystemApi class

Constructors

MattermostSystemApi(MattermostApiClient apiClient)

Properties

apiClient → MattermostApiClient
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkIntegrity() → Future<List<MmIntegrityCheckResult>?>
Perform a database integrity check
checkIntegrityWithHttpInfo() → Future<Response>
Perform a database integrity check
clearServerBusy() → Future<MmStatusOK?>
Clears the server busy (high load) flag
clearServerBusyWithHttpInfo() → Future<Response>
Clears the server busy (high load) flag
databaseRecycle() → Future<MmStatusOK?>
Recycle database connections
databaseRecycleWithHttpInfo() → Future<Response>
Recycle database connections
generateSupportPacket() → Future<void>
Download a zip file which contains helpful and useful information for troubleshooting your mattermost instance.
generateSupportPacketWithHttpInfo() → Future<Response>
Download a zip file which contains helpful and useful information for troubleshooting your mattermost instance.
getAnalyticsOld({String? name, String? teamId}) → Future<void>
Get analytics
getAnalyticsOldWithHttpInfo({String? name, String? teamId}) → Future<Response>
Get analytics
getAudits({int? page, int? perPage}) → Future<List<MmAudit>?>
Get audits
getAuditsWithHttpInfo({int? page, int? perPage}) → Future<Response>
Get audits
getClientConfig(String format) → Future<void>
Get client configuration
getClientConfigWithHttpInfo(String format) → Future<Response>
Get client configuration
getClientLicense(String format) → Future<void>
Get client license
getClientLicenseWithHttpInfo(String format) → Future<Response>
Get client license
getConfig() → Future<MmConfig?>
Get configuration
getConfigWithHttpInfo() → Future<Response>
Get configuration
getEnvironmentConfig() → Future<MmEnvironmentConfig?>
Get configuration made through environment variables
getEnvironmentConfigWithHttpInfo() → Future<Response>
Get configuration made through environment variables
getImageByUrl() → Future<MultipartFile?>
Get an image by url
getImageByUrlWithHttpInfo() → Future<Response>
Get an image by url
getLogs({int? page, String? logsPerPage}) → Future<List<String>?>
Get logs
getLogsWithHttpInfo({int? page, String? logsPerPage}) → Future<Response>
Get logs
getNotices(String clientVersion, String client, String teamId, {String? locale}) → Future<List<MmNotice>?>
Get notices for logged in user in specified team
getNoticesWithHttpInfo(String clientVersion, String client, String teamId, {String? locale}) → Future<Response>
Get notices for logged in user in specified team
getPing({bool? getServerStatus, String? deviceId}) → Future<MmSystemStatusResponse?>
Check system health
getPingWithHttpInfo({bool? getServerStatus, String? deviceId}) → Future<Response>
Check system health
getRedirectLocation(String url) → Future<MmGetRedirectLocation200Response?>
Get redirect location
getRedirectLocationWithHttpInfo(String url) → Future<Response>
Get redirect location
getServerBusyExpires() → Future<MmServerBusy?>
Get server busy expiry time.
getServerBusyExpiresWithHttpInfo() → Future<Response>
Get server busy expiry time.
getSupportedTimezone() → Future<List<String>?>
Retrieve a list of supported timezones
getSupportedTimezoneWithHttpInfo() → Future<Response>
Retrieve a list of supported timezones
getWarnMetricsStatus() → Future<MmStatusOK?>
Get the warn metrics status (enabled or disabled)
getWarnMetricsStatusWithHttpInfo() → Future<Response>
Get the warn metrics status (enabled or disabled)
invalidateCaches() → Future<MmStatusOK?>
Invalidate all the caches
invalidateCachesWithHttpInfo() → Future<Response>
Invalidate all the caches
markNoticesViewed(List<String> requestBody) → Future<MmStatusOK?>
Update notices as 'viewed'
markNoticesViewedWithHttpInfo(List<String> requestBody) → Future<Response>
Update notices as 'viewed'
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patchConfig(MmConfig mmConfig) → Future<MmConfig?>
Patch configuration
patchConfigWithHttpInfo(MmConfig mmConfig) → Future<Response>
Patch configuration
postLog(MmPostLogRequest mmPostLogRequest) → Future<List<String>?>
Add log message
postLogWithHttpInfo(MmPostLogRequest mmPostLogRequest) → Future<Response>
Add log message
reloadConfig() → Future<MmStatusOK?>
Reload configuration
reloadConfigWithHttpInfo() → Future<Response>
Reload configuration
removeLicenseFile() → Future<void>
Remove license file
removeLicenseFileWithHttpInfo() → Future<Response>
Remove license file
Request the license renewal link
requestLicenseRenewalLinkWithHttpInfo() → Future<Response>
Request the license renewal link
requestTrialLicense(MmRequestTrialLicenseRequest mmRequestTrialLicenseRequest) → Future<void>
Request and install a trial license for your server
requestTrialLicenseWithHttpInfo(MmRequestTrialLicenseRequest mmRequestTrialLicenseRequest) → Future<Response>
Request and install a trial license for your server
restartServer() → Future<MmStatusOK?>
Restart the system after an upgrade from Team Edition to Enterprise Edition
restartServerWithHttpInfo() → Future<Response>
Restart the system after an upgrade from Team Edition to Enterprise Edition
sendTrialLicenseWarnMetricAck(String warnMetricId) → Future<MmStatusOK?>
Request trial license and acknowledge a warning of a metric status
sendTrialLicenseWarnMetricAckWithHttpInfo(String warnMetricId) → Future<Response>
Request trial license and acknowledge a warning of a metric status
sendWarnMetricAck(String warnMetricId, MmSendWarnMetricAckRequest mmSendWarnMetricAckRequest) → Future<MmStatusOK?>
Acknowledge a warning of a metric status
sendWarnMetricAckWithHttpInfo(String warnMetricId, MmSendWarnMetricAckRequest mmSendWarnMetricAckRequest) → Future<Response>
Acknowledge a warning of a metric status
setServerBusy({String? seconds}) → Future<MmStatusOK?>
Set the server busy (high load) flag
setServerBusyWithHttpInfo({String? seconds}) → Future<Response>
Set the server busy (high load) flag
testEmail(MmConfig mmConfig) → Future<MmStatusOK?>
Send a test email
testEmailWithHttpInfo(MmConfig mmConfig) → Future<Response>
Send a test email
testS3Connection(MmConfig mmConfig) → Future<MmStatusOK?>
Test AWS S3 connection
testS3ConnectionWithHttpInfo(MmConfig mmConfig) → Future<Response>
Test AWS S3 connection
testSiteURL(MmTestSiteURLRequest mmTestSiteURLRequest) → Future<MmStatusOK?>
Checks the validity of a Site URL
testSiteURLWithHttpInfo(MmTestSiteURLRequest mmTestSiteURLRequest) → Future<Response>
Checks the validity of a Site URL
toString() → String
A string representation of this object.
inherited
trialLicensePrevGet() → Future<void>
Get last trial license used
trialLicensePrevGetWithHttpInfo() → Future<Response>
Get last trial license used
updateConfig(MmConfig mmConfig) → Future<MmConfig?>
Update configuration
updateConfigWithHttpInfo(MmConfig mmConfig) → Future<Response>
Update configuration
updateMarketplaceVisitedByAdmin(MmSystem mmSystem) → Future<MmStatusOK?>
Stores that the Plugin Marketplace has been visited by at least an admin.
updateMarketplaceVisitedByAdminWithHttpInfo(MmSystem mmSystem) → Future<Response>
Stores that the Plugin Marketplace has been visited by at least an admin.
upgradeToEnterprise() → Future<MmPushNotification?>
Executes an inplace upgrade from Team Edition to Enterprise Edition
upgradeToEnterpriseStatus() → Future<MmUpgradeToEnterpriseStatus200Response?>
Get the current status for the inplace upgrade from Team Edition to Enterprise Edition
upgradeToEnterpriseStatusWithHttpInfo() → Future<Response>
Get the current status for the inplace upgrade from Team Edition to Enterprise Edition
upgradeToEnterpriseWithHttpInfo() → Future<Response>
Executes an inplace upgrade from Team Edition to Enterprise Edition
uploadLicenseFile(MultipartFile license) → Future<MmStatusOK?>
Upload license file
uploadLicenseFileWithHttpInfo(MultipartFile license) → Future<Response>
Upload license file

Operators

operator ==(Object other) → bool
The equality operator.
inherited