MattermostThreadsApi class

Constructors

MattermostThreadsApi(MattermostApiClient apiClient)

Properties

apiClient → MattermostApiClient
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getThreadMentionCountsByChannel(String userId, String teamId) → Future<void>
Get all unread mention counts from followed threads, per-channel
getThreadMentionCountsByChannelWithHttpInfo(String userId, String teamId) → Future<Response>
Get all unread mention counts from followed threads, per-channel
getUserThread(String userId, String teamId, String threadId) → Future<void>
Get a thread followed by the user
getUserThreads(String userId, String teamId, {int? since, bool? deleted, bool? extended, int? page, int? pageSize, bool? totalsOnly}) → Future<MmUserThreads?>
Get all threads that user is following
getUserThreadsWithHttpInfo(String userId, String teamId, {int? since, bool? deleted, bool? extended, int? page, int? pageSize, bool? totalsOnly}) → Future<Response>
Get all threads that user is following
getUserThreadWithHttpInfo(String userId, String teamId, String threadId) → Future<Response>
Get a thread followed by the user
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startFollowingThread(String userId, String teamId, String threadId) → Future<void>
Start following a thread
startFollowingThreadWithHttpInfo(String userId, String teamId, String threadId) → Future<Response>
Start following a thread
stopFollowingThread(String userId, String teamId, String threadId) → Future<void>
Stop following a thread
stopFollowingThreadWithHttpInfo(String userId, String teamId, String threadId) → Future<Response>
Stop following a thread
toString() → String
A string representation of this object.
inherited
updateThreadReadForUser(String userId, String teamId, String threadId, String timestamp) → Future<void>
Mark a thread that user is following read state to the timestamp
updateThreadReadForUserWithHttpInfo(String userId, String teamId, String threadId, String timestamp) → Future<Response>
Mark a thread that user is following read state to the timestamp
updateThreadsReadForUser(String userId, String teamId) → Future<void>
Mark all threads that user is following as read
updateThreadsReadForUserWithHttpInfo(String userId, String teamId) → Future<Response>
Mark all threads that user is following as read

Operators

operator ==(Object other) → bool
The equality operator.
inherited