MattermostWebhooksApi class

Constructors

MattermostWebhooksApi(MattermostApiClient apiClient)

Properties

apiClient → MattermostApiClient
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createIncomingWebhook(MmCreateIncomingWebhookRequest mmCreateIncomingWebhookRequest) → Future<MmIncomingWebhook?>
Create an incoming webhook
createIncomingWebhookWithHttpInfo(MmCreateIncomingWebhookRequest mmCreateIncomingWebhookRequest) → Future<Response>
Create an incoming webhook
createOutgoingWebhook(MmCreateOutgoingWebhookRequest mmCreateOutgoingWebhookRequest) → Future<MmOutgoingWebhook?>
Create an outgoing webhook
createOutgoingWebhookWithHttpInfo(MmCreateOutgoingWebhookRequest mmCreateOutgoingWebhookRequest) → Future<Response>
Create an outgoing webhook
deleteIncomingWebhook(String hookId) → Future<MmStatusOK?>
Delete an incoming webhook
deleteIncomingWebhookWithHttpInfo(String hookId) → Future<Response>
Delete an incoming webhook
deleteOutgoingWebhook(String hookId) → Future<MmStatusOK?>
Delete an outgoing webhook
deleteOutgoingWebhookWithHttpInfo(String hookId) → Future<Response>
Delete an outgoing webhook
getIncomingWebhook(String hookId) → Future<MmIncomingWebhook?>
Get an incoming webhook
getIncomingWebhooks({int? page, int? perPage, String? teamId}) → Future<List<MmIncomingWebhook>?>
List incoming webhooks
getIncomingWebhooksWithHttpInfo({int? page, int? perPage, String? teamId}) → Future<Response>
List incoming webhooks
getIncomingWebhookWithHttpInfo(String hookId) → Future<Response>
Get an incoming webhook
getOutgoingWebhook(String hookId) → Future<MmOutgoingWebhook?>
Get an outgoing webhook
getOutgoingWebhooks({int? page, int? perPage, String? teamId, String? channelId}) → Future<List<MmOutgoingWebhook>?>
List outgoing webhooks
getOutgoingWebhooksWithHttpInfo({int? page, int? perPage, String? teamId, String? channelId}) → Future<Response>
List outgoing webhooks
getOutgoingWebhookWithHttpInfo(String hookId) → Future<Response>
Get an outgoing webhook
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
regenOutgoingHookToken(String hookId) → Future<MmStatusOK?>
Regenerate the token for the outgoing webhook.
regenOutgoingHookTokenWithHttpInfo(String hookId) → Future<Response>
Regenerate the token for the outgoing webhook.
toString() → String
A string representation of this object.
inherited
updateIncomingWebhook(String hookId, MmUpdateIncomingWebhookRequest mmUpdateIncomingWebhookRequest) → Future<MmIncomingWebhook?>
Update an incoming webhook
updateIncomingWebhookWithHttpInfo(String hookId, MmUpdateIncomingWebhookRequest mmUpdateIncomingWebhookRequest) → Future<Response>
Update an incoming webhook
updateOutgoingWebhook(String hookId, MmUpdateOutgoingWebhookRequest mmUpdateOutgoingWebhookRequest) → Future<MmOutgoingWebhook?>
Update an outgoing webhook
updateOutgoingWebhookWithHttpInfo(String hookId, MmUpdateOutgoingWebhookRequest mmUpdateOutgoingWebhookRequest) → Future<Response>
Update an outgoing webhook

Operators

operator ==(Object other) → bool
The equality operator.
inherited