MmApiKeyAuthentication class

Implemented types

Constructors

MmApiKeyAuthentication(MmHttpLocation location, String paramName, String apiKey, {String apiKeyPrefix = ''})

Properties

apiKey ↔ String
getter/setter pair
apiKeyPrefix ↔ String
if set, the apiKeyPrefix will be prepended to the apiKey and separated by a space character
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
location → MmHttpLocation
location can be 'query', 'header', or 'cookie'
final
paramName → String
paramName is the name of the parameter to use for sending the api key
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyToParams(List<MmQueryParam> queryParams, Map<String, String> headerParams) → void
Apply authentication settings to header and query params.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited