MmAutocompleteSuggestion class

Constructors

MmAutocompleteSuggestion({String? complete, String? suggestion, String? hint, String? description, String? iconData})
Returns a new MmAutocompleteSuggestion instance.

Properties

complete ↔ String?
Completed suggestion
getter/setter pair
description ↔ String?
Description of the suggested command
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
hint ↔ String?
Hint about suggested input
getter/setter pair
iconData ↔ String?
Base64 encoded svg image
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestion ↔ String?
Predicted text user might want to input
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmAutocompleteSuggestion?
Returns a new MmAutocompleteSuggestion instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmAutocompleteSuggestion>?
mapFromJson(dynamic json) → Map<String, MmAutocompleteSuggestion>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmAutocompleteSuggestion>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.