MmChannelNotifyProps class

Constructors

MmChannelNotifyProps({bool? email, String? push, String? desktop, String? markUnread})
Returns a new MmChannelNotifyProps instance.

Properties

desktop ↔ String?
Set to "all" to receive desktop notifications for all activity, "mention" for mentions and direct messages only, "none" to disable, or "default" to use the global user notification setting.
getter/setter pair
email ↔ bool?
Set to "true" to enable email notifications, "false" to disable, or "default" to use the global user notification setting.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
markUnread ↔ String?
Set to "all" to mark the channel unread for any new message, "mention" to mark unread for new mentions only. Defaults to "all".
getter/setter pair
push ↔ String?
Set to "all" to receive push notifications for all activity, "mention" for mentions and direct messages only, "none" to disable, or "default" to use the global user notification setting.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmChannelNotifyProps?
Returns a new MmChannelNotifyProps instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmChannelNotifyProps>?
mapFromJson(dynamic json) → Map<String, MmChannelNotifyProps>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmChannelNotifyProps>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.