MmChannelUnreadAt class

Constructors

MmChannelUnreadAt({String? teamId, String? channelId, int? msgCount, int? mentionCount, int? lastViewedAt})
Returns a new MmChannelUnreadAt instance.

Properties

channelId ↔ String?
The ID of the channel the user has access to..
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
lastViewedAt ↔ int?
time in milliseconds when the user last viewed the channel.
getter/setter pair
mentionCount ↔ int?
No. of mentions the user has within the unread posts of the channel.
getter/setter pair
msgCount ↔ int?
No. of messages the user has already read.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teamId ↔ String?
The ID of the team the channel belongs to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmChannelUnreadAt?
Returns a new MmChannelUnreadAt instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmChannelUnreadAt>?
mapFromJson(dynamic json) → Map<String, MmChannelUnreadAt>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmChannelUnreadAt>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.