MmChannelWithTeamData class

Constructors

MmChannelWithTeamData({String? id, int? createAt, int? updateAt, int? deleteAt, String? teamId, String? type, String? displayName, String? name, String? header, String? purpose, int? lastPostAt, int? totalMsgCount, int? extraUpdateAt, String? creatorId, String? teamDisplayName, String? teamName, int? teamUpdateAt, String? policyId})
Returns a new MmChannelWithTeamData instance.

Properties

createAt ↔ int?
The time in milliseconds a channel was created
getter/setter pair
creatorId ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
deleteAt ↔ int?
The time in milliseconds a channel was deleted
getter/setter pair
displayName ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
extraUpdateAt ↔ int?
Deprecated in Mattermost 5.0 release
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
id ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
lastPostAt ↔ int?
The time in milliseconds of the last post of a channel
getter/setter pair
name ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
policyId ↔ String?
The data retention policy to which this team has been assigned. If no such policy exists, or the caller does not have the sysconsole_read_compliance_data_retention permission, this field will be null.
getter/setter pair
purpose ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teamDisplayName ↔ String?
The display name of the team to which this channel belongs.
getter/setter pair
teamId ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
teamName ↔ String?
The name of the team to which this channel belongs.
getter/setter pair
teamUpdateAt ↔ int?
The time at which the team to which this channel belongs was last updated.
getter/setter pair
totalMsgCount ↔ int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
type ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
updateAt ↔ int?
The time in milliseconds a channel was last updated
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmChannelWithTeamData?
Returns a new MmChannelWithTeamData instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmChannelWithTeamData>?
mapFromJson(dynamic json) → Map<String, MmChannelWithTeamData>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmChannelWithTeamData>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.