MmChannelWithTeamDataAllOf class

Constructors

MmChannelWithTeamDataAllOf({String? teamDisplayName, String? teamName, int? teamUpdateAt, String? policyId})
Returns a new MmChannelWithTeamDataAllOf instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
policyId ↔ String?
The data retention policy to which this team has been assigned. If no such policy exists, or the caller does not have the sysconsole_read_compliance_data_retention permission, this field will be null.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teamDisplayName ↔ String?
The display name of the team to which this channel belongs.
getter/setter pair
teamName ↔ String?
The name of the team to which this channel belongs.
getter/setter pair
teamUpdateAt ↔ int?
The time at which the team to which this channel belongs was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmChannelWithTeamDataAllOf?
Returns a new MmChannelWithTeamDataAllOf instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmChannelWithTeamDataAllOf>?
mapFromJson(dynamic json) → Map<String, MmChannelWithTeamDataAllOf>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmChannelWithTeamDataAllOf>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.