MmClusterInfo class

Constructors

MmClusterInfo({String? id, String? version, String? configHash, String? internodeUrl, String? hostname, int? lastPing, bool? isAlive})
Returns a new MmClusterInfo instance.

Properties

configHash ↔ String?
The hash of the configuartion file the node is using
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
hostname ↔ String?
The hostname for this node
getter/setter pair
id ↔ String?
The unique ID for the node
getter/setter pair
internodeUrl ↔ String?
The URL used to communicate with those node from other nodes
getter/setter pair
isAlive ↔ bool?
Whether or not the node is alive and well
getter/setter pair
lastPing ↔ int?
The time of the last ping to this node
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String?
The server version the node is on
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmClusterInfo?
Returns a new MmClusterInfo instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmClusterInfo>?
mapFromJson(dynamic json) → Map<String, MmClusterInfo>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmClusterInfo>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.