MmCommand class

Constructors

MmCommand({String? id, String? token, int? createAt, int? updateAt, int? deleteAt, String? creatorId, String? teamId, String? trigger, String? method, String? username, String? iconUrl, bool? autoComplete, String? autoCompleteDesc, String? autoCompleteHint, String? displayName, String? description, String? url})
Returns a new MmCommand instance.

Properties

autoComplete ↔ bool?
Use auto complete for this command
getter/setter pair
autoCompleteDesc ↔ String?
The description for this command shown when selecting the command
getter/setter pair
autoCompleteHint ↔ String?
The hint for this command
getter/setter pair
createAt ↔ int?
The time in milliseconds the command was created
getter/setter pair
creatorId ↔ String?
The user id for the commands creator
getter/setter pair
deleteAt ↔ int?
The time in milliseconds the command was deleted, 0 if never deleted
getter/setter pair
description ↔ String?
Description for this command
getter/setter pair
displayName ↔ String?
Display name for the command
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
iconUrl ↔ String?
The url to find the icon for this users avatar
getter/setter pair
id ↔ String?
The ID of the slash command
getter/setter pair
method ↔ String?
Is the trigger done with HTTP Get ('G') or HTTP Post ('P')
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teamId ↔ String?
The team id for which this command is configured
getter/setter pair
token ↔ String?
The token which is used to verify the source of the payload
getter/setter pair
trigger ↔ String?
The string that triggers this command
getter/setter pair
updateAt ↔ int?
The time in milliseconds the command was last updated
getter/setter pair
url ↔ String?
The URL that is triggered
getter/setter pair
username ↔ String?
What is the username for the response post
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmCommand?
Returns a new MmCommand instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmCommand>?
mapFromJson(dynamic json) → Map<String, MmCommand>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmCommand>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.