MmConfig class

Constructors

MmConfig({MmConfigServiceSettings? serviceSettings, MmConfigTeamSettings? teamSettings, MmConfigSqlSettings? sqlSettings, MmConfigLogSettings? logSettings, MmConfigPasswordSettings? passwordSettings, MmConfigFileSettings? fileSettings, MmConfigEmailSettings? emailSettings, MmConfigRateLimitSettings? rateLimitSettings, MmConfigPrivacySettings? privacySettings, MmConfigSupportSettings? supportSettings, MmConfigGitLabSettings? gitLabSettings, MmConfigGitLabSettings? googleSettings, MmConfigGitLabSettings? office365Settings, MmConfigLdapSettings? ldapSettings, MmConfigComplianceSettings? complianceSettings, MmConfigLocalizationSettings? localizationSettings, MmConfigSamlSettings? samlSettings, MmConfigNativeAppSettings? nativeAppSettings, MmConfigClusterSettings? clusterSettings, MmConfigMetricsSettings? metricsSettings, MmConfigAnalyticsSettings? analyticsSettings})
Returns a new MmConfig instance.

Properties

analyticsSettings ↔ MmConfigAnalyticsSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
clusterSettings ↔ MmConfigClusterSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
complianceSettings ↔ MmConfigComplianceSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
emailSettings ↔ MmConfigEmailSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
fileSettings ↔ MmConfigFileSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
gitLabSettings ↔ MmConfigGitLabSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
googleSettings ↔ MmConfigGitLabSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
ldapSettings ↔ MmConfigLdapSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
localizationSettings ↔ MmConfigLocalizationSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
logSettings ↔ MmConfigLogSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
metricsSettings ↔ MmConfigMetricsSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
nativeAppSettings ↔ MmConfigNativeAppSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
office365Settings ↔ MmConfigGitLabSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
passwordSettings ↔ MmConfigPasswordSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
privacySettings ↔ MmConfigPrivacySettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
rateLimitSettings ↔ MmConfigRateLimitSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samlSettings ↔ MmConfigSamlSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
serviceSettings ↔ MmConfigServiceSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
sqlSettings ↔ MmConfigSqlSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
supportSettings ↔ MmConfigSupportSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
teamSettings ↔ MmConfigTeamSettings?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmConfig?
Returns a new MmConfig instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmConfig>?
mapFromJson(dynamic json) → Map<String, MmConfig>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmConfig>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.