MmCreateChannelRequest class

Constructors

MmCreateChannelRequest({required String teamId, required String name, required String displayName, String? purpose, String? header, required String type})
Returns a new MmCreateChannelRequest instance.

Properties

displayName ↔ String
The non-unique UI name for the channel
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
Markdown-formatted text to display in the header of the channel
getter/setter pair
name ↔ String
The unique handle for the channel, will be present in the channel URL
getter/setter pair
purpose ↔ String?
A short description of the purpose of the channel
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teamId ↔ String
The team ID of the team to create the channel on
getter/setter pair
type ↔ String
'O' for a public channel, 'P' for a private channel
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmCreateChannelRequest?
Returns a new MmCreateChannelRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmCreateChannelRequest>?
mapFromJson(dynamic json) → Map<String, MmCreateChannelRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmCreateChannelRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.