MmCreateCommandRequest class

Constructors

MmCreateCommandRequest({required String teamId, required String method, required String trigger, required String url})
Returns a new MmCreateCommandRequest instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
method ↔ String
'P' for post request, 'G' for get request
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teamId ↔ String
Team ID to where the command should be created
getter/setter pair
trigger ↔ String
Activation word to trigger the command
getter/setter pair
url ↔ String
The URL that the command will make the request
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmCreateCommandRequest?
Returns a new MmCreateCommandRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmCreateCommandRequest>?
mapFromJson(dynamic json) → Map<String, MmCreateCommandRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmCreateCommandRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.