MmCreateIncomingWebhookRequest class

Constructors

MmCreateIncomingWebhookRequest({required String channelId, String? userId, String? displayName, String? description, String? username, String? iconUrl})
Returns a new MmCreateIncomingWebhookRequest instance.

Properties

channelId ↔ String
The ID of a public channel or private group that receives the webhook payloads.
getter/setter pair
description ↔ String?
The description for this incoming webhook
getter/setter pair
displayName ↔ String?
The display name for this incoming webhook
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
iconUrl ↔ String?
The profile picture this incoming webhook will use when posting.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId ↔ String?
The ID of the owner of the webhook if different than the requester. Required for local mode.
getter/setter pair
username ↔ String?
The username this incoming webhook will post as.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmCreateIncomingWebhookRequest?
Returns a new MmCreateIncomingWebhookRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmCreateIncomingWebhookRequest>?
mapFromJson(dynamic json) → Map<String, MmCreateIncomingWebhookRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmCreateIncomingWebhookRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.