MmCreateJobRequest class

Constructors

MmCreateJobRequest({required String type, Map? data})
Returns a new MmCreateJobRequest instance.

Properties

data ↔ Map?
An object containing any additional data required for this job type
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
The type of job to create
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmCreateJobRequest?
Returns a new MmCreateJobRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmCreateJobRequest>?
mapFromJson(dynamic json) → Map<String, MmCreateJobRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmCreateJobRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.