MmCreateOAuthAppRequest class

Constructors

MmCreateOAuthAppRequest({required String name, required String description, String? iconUrl, List<String> callbackUrls = const [], required String homepage, bool? isTrusted})
Returns a new MmCreateOAuthAppRequest instance.

Properties

callbackUrls ↔ List<String>
A list of callback URLs for the appliation
getter/setter pair
description ↔ String
A short description of the application
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
homepage ↔ String
A link to the website of the application
getter/setter pair
iconUrl ↔ String?
A URL to an icon to display with the application
getter/setter pair
isTrusted ↔ bool?
Set this to true to skip asking users for permission
getter/setter pair
name ↔ String
The name of the client application
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmCreateOAuthAppRequest?
Returns a new MmCreateOAuthAppRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmCreateOAuthAppRequest>?
mapFromJson(dynamic json) → Map<String, MmCreateOAuthAppRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmCreateOAuthAppRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.