MmCreateSchemeRequest class

Constructors

MmCreateSchemeRequest({required String name, String? description, required String scope})
Returns a new MmCreateSchemeRequest instance.

Properties

description ↔ String?
The description of the scheme
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
name ↔ String
The name of the scheme
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String
The scope of the scheme ("team" or "channel")
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmCreateSchemeRequest?
Returns a new MmCreateSchemeRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmCreateSchemeRequest>?
mapFromJson(dynamic json) → Map<String, MmCreateSchemeRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmCreateSchemeRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.