MmCreateTeamRequest class

Constructors

MmCreateTeamRequest({required String name, required String displayName, required String type})
Returns a new MmCreateTeamRequest instance.

Properties

displayName ↔ String
Non-unique UI name for the team
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
name ↔ String
Unique handler for a team, will be present in the team URL
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
'O' for open, 'I' for invite only
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmCreateTeamRequest?
Returns a new MmCreateTeamRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmCreateTeamRequest>?
mapFromJson(dynamic json) → Map<String, MmCreateTeamRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmCreateTeamRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.