MmDataRetentionPolicyWithTeamAndChannelCountsAllOf class

Constructors

MmDataRetentionPolicyWithTeamAndChannelCountsAllOf({int? teamCount, int? channelCount})
Returns a new MmDataRetentionPolicyWithTeamAndChannelCountsAllOf instance.

Properties

channelCount ↔ int?
The number of channels to which this policy is applied.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teamCount ↔ int?
The number of teams to which this policy is applied.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmDataRetentionPolicyWithTeamAndChannelCountsAllOf?
Returns a new MmDataRetentionPolicyWithTeamAndChannelCountsAllOf instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmDataRetentionPolicyWithTeamAndChannelCountsAllOf>?
mapFromJson(dynamic json) → Map<String, MmDataRetentionPolicyWithTeamAndChannelCountsAllOf>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmDataRetentionPolicyWithTeamAndChannelCountsAllOf>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.