MmDataRetentionPolicyWithoutId class

Constructors

MmDataRetentionPolicyWithoutId({String? displayName, int? postDuration})
Returns a new MmDataRetentionPolicyWithoutId instance.

Properties

displayName ↔ String?
The display name for this retention policy.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
postDuration ↔ int?
The number of days a message will be retained before being deleted by this policy. If this value is less than 0, the policy has infinite retention (i.e. messages are never deleted).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmDataRetentionPolicyWithoutId?
Returns a new MmDataRetentionPolicyWithoutId instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmDataRetentionPolicyWithoutId>?
mapFromJson(dynamic json) → Map<String, MmDataRetentionPolicyWithoutId>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmDataRetentionPolicyWithoutId>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.