MmEmoji class

Constructors

MmEmoji({String? id, String? creatorId, String? name, int? createAt, int? updateAt, int? deleteAt})
Returns a new MmEmoji instance.

Properties

createAt ↔ int?
The time in milliseconds the emoji was made
getter/setter pair
creatorId ↔ String?
The ID of the user that made the emoji
getter/setter pair
deleteAt ↔ int?
The time in milliseconds the emoji was deleted
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
The ID of the emoji
getter/setter pair
name ↔ String?
The name of the emoji
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateAt ↔ int?
The time in milliseconds the emoji was last updated
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmEmoji?
Returns a new MmEmoji instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmEmoji>?
mapFromJson(dynamic json) → Map<String, MmEmoji>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmEmoji>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.