MmEnvironmentConfigSqlSettings class

Constructors

MmEnvironmentConfigSqlSettings({bool? driverName, bool? dataSource, bool? dataSourceReplicas, bool? maxIdleConns, bool? maxOpenConns, bool? trace, bool? atRestEncryptKey})
Returns a new MmEnvironmentConfigSqlSettings instance.

Properties

atRestEncryptKey ↔ bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
dataSource ↔ bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
dataSourceReplicas ↔ bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
driverName ↔ bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
maxIdleConns ↔ bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
maxOpenConns ↔ bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trace ↔ bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmEnvironmentConfigSqlSettings?
Returns a new MmEnvironmentConfigSqlSettings instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmEnvironmentConfigSqlSettings>?
mapFromJson(dynamic json) → Map<String, MmEnvironmentConfigSqlSettings>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmEnvironmentConfigSqlSettings>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.