MmExecuteCommandRequest class

Constructors

MmExecuteCommandRequest({required String channelId, required String command})
Returns a new MmExecuteCommandRequest instance.

Properties

channelId ↔ String
Channel Id where the command will execute
getter/setter pair
command ↔ String
The slash command to execute
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmExecuteCommandRequest?
Returns a new MmExecuteCommandRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmExecuteCommandRequest>?
mapFromJson(dynamic json) → Map<String, MmExecuteCommandRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmExecuteCommandRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.