MmFileInfoList class

Constructors

MmFileInfoList({List<String> order = const [], Map<String, MmFileInfo> fileInfos = const {}, String? nextFileId, String? prevFileId})
Returns a new MmFileInfoList instance.

Properties

fileInfos ↔ Map<String, MmFileInfo>
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
nextFileId ↔ String?
The ID of next file info. Not omitted when empty or not relevant.
getter/setter pair
order ↔ List<String>
getter/setter pair
prevFileId ↔ String?
The ID of previous file info. Not omitted when empty or not relevant.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmFileInfoList?
Returns a new MmFileInfoList instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmFileInfoList>?
mapFromJson(dynamic json) → Map<String, MmFileInfoList>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmFileInfoList>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.