MmFilesLimits class

Constructors

MmFilesLimits({int? totalStorage})
Returns a new MmFilesLimits instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalStorage ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmFilesLimits?
Returns a new MmFilesLimits instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmFilesLimits>?
mapFromJson(dynamic json) → Map<String, MmFilesLimits>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmFilesLimits>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.