MmGetPlugins200Response class

Constructors

MmGetPlugins200Response({List<MmPluginManifest> active = const [], List<MmPluginManifest> inactive = const []})
Returns a new MmGetPlugins200Response instance.

Properties

active ↔ List<MmPluginManifest>
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
inactive ↔ List<MmPluginManifest>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmGetPlugins200Response?
Returns a new MmGetPlugins200Response instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmGetPlugins200Response>?
mapFromJson(dynamic json) → Map<String, MmGetPlugins200Response>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmGetPlugins200Response>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.