MmGetUsersByGroupChannelIds200Response class

Constructors

MmGetUsersByGroupChannelIds200Response({List<MmUser> lessThanCHANNELIDGreaterThan = const []})
Returns a new MmGetUsersByGroupChannelIds200Response instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
lessThanCHANNELIDGreaterThan ↔ List<MmUser>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmGetUsersByGroupChannelIds200Response?
Returns a new MmGetUsersByGroupChannelIds200Response instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmGetUsersByGroupChannelIds200Response>?
mapFromJson(dynamic json) → Map<String, MmGetUsersByGroupChannelIds200Response>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmGetUsersByGroupChannelIds200Response>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.