MmGlobalDataRetentionPolicy class

Constructors

MmGlobalDataRetentionPolicy({bool? messageDeletionEnabled, bool? fileDeletionEnabled, int? messageRetentionCutoff, int? fileRetentionCutoff})
Returns a new MmGlobalDataRetentionPolicy instance.

Properties

fileDeletionEnabled ↔ bool?
Indicates whether data retention policy deletion of file attachments is enabled globally.
getter/setter pair
fileRetentionCutoff ↔ int?
The current server timestamp before which files should be deleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
messageDeletionEnabled ↔ bool?
Indicates whether data retention policy deletion of messages is enabled globally.
getter/setter pair
messageRetentionCutoff ↔ int?
The current server timestamp before which messages should be deleted.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmGlobalDataRetentionPolicy?
Returns a new MmGlobalDataRetentionPolicy instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmGlobalDataRetentionPolicy>?
mapFromJson(dynamic json) → Map<String, MmGlobalDataRetentionPolicy>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmGlobalDataRetentionPolicy>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.