MmHttpBasicAuthentication class

Implemented types

Constructors

MmHttpBasicAuthentication({String username = '', String password = ''})

Properties

hashCode → int
The hash code for this object.
no setterinherited
password ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username ↔ String
getter/setter pair

Methods

applyToParams(List<MmQueryParam> queryParams, Map<String, String> headerParams) → void
Apply authentication settings to header and query params.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited