MmIncomingWebhook class

Constructors

MmIncomingWebhook({String? id, int? createAt, int? updateAt, int? deleteAt, String? channelId, String? description, String? displayName})
Returns a new MmIncomingWebhook instance.

Properties

channelId ↔ String?
The ID of a public channel or private group that receives the webhook payloads
getter/setter pair
createAt ↔ int?
The time in milliseconds a incoming webhook was created
getter/setter pair
deleteAt ↔ int?
The time in milliseconds a incoming webhook was deleted
getter/setter pair
description ↔ String?
The description for this incoming webhook
getter/setter pair
displayName ↔ String?
The display name for this incoming webhook
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
The unique identifier for this incoming webhook
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateAt ↔ int?
The time in milliseconds a incoming webhook was last updated
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmIncomingWebhook?
Returns a new MmIncomingWebhook instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmIncomingWebhook>?
mapFromJson(dynamic json) → Map<String, MmIncomingWebhook>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmIncomingWebhook>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.