MmJob class

Constructors

MmJob({String? id, String? type, int? createAt, int? startAt, int? lastActivityAt, String? status, int? progress, Map? data})
Returns a new MmJob instance.

Properties

createAt ↔ int?
The time at which the job was created
getter/setter pair
data ↔ Map?
A freeform data field containing additional information about the job
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
The unique id of the job
getter/setter pair
lastActivityAt ↔ int?
The last time at which the job had activity
getter/setter pair
progress ↔ int?
The progress (as a percentage) of the job
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startAt ↔ int?
The time at which the job was started
getter/setter pair
status ↔ String?
The status of the job
getter/setter pair
type ↔ String?
The type of job
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmJob?
Returns a new MmJob instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmJob>?
mapFromJson(dynamic json) → Map<String, MmJob>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmJob>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.