MmNotice class

Constructors

MmNotice({String? id, bool? sysAdminOnly, bool? teamAdminOnly, String? action, String? actionParam, String? actionText, String? description, String? image, String? title})
Returns a new MmNotice instance.

Properties

action ↔ String?
Optional action to perform on action button click. (defaults to closing the notice)
getter/setter pair
actionParam ↔ String?
Optional action parameter. Example: {"action": "url", actionParam: "/console/some-page"}
getter/setter pair
actionText ↔ String?
Optional override for the action button text (defaults to OK)
getter/setter pair
description ↔ String?
Notice content. Use {{Mattermost}} instead of plain text to support white-labeling. Text supports Markdown.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
Notice ID
getter/setter pair
image ↔ String?
URL of image to display
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sysAdminOnly ↔ bool?
Does this notice apply only to sysadmins
getter/setter pair
teamAdminOnly ↔ bool?
Does this notice apply only to team admins
getter/setter pair
title ↔ String?
Notice title. Use {{Mattermost}} instead of plain text to support white-labeling. Text supports Markdown.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmNotice?
Returns a new MmNotice instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmNotice>?
mapFromJson(dynamic json) → Map<String, MmNotice>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmNotice>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.