MmOpenGraph class

Constructors

MmOpenGraph({String? type, String? url, String? title, String? description, String? determiner, String? siteName, String? locale, List<String> localesAlternate = const [], List<MmOpenGraphImagesInner> images = const [], List<MmOpenGraphVideosInner> videos = const [], List<MmOpenGraphAudiosInner> audios = const [], MmOpenGraphArticle? article, MmOpenGraphBook? book, MmOpenGraphArticleAuthorsInner? profile})
Returns a new MmOpenGraph instance.

Properties

article ↔ MmOpenGraphArticle?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
audios ↔ List<MmOpenGraphAudiosInner>
getter/setter pair
book ↔ MmOpenGraphBook?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
description ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
determiner ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
images ↔ List<MmOpenGraphImagesInner>
getter/setter pair
locale ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
localesAlternate ↔ List<String>
getter/setter pair
profile ↔ MmOpenGraphArticleAuthorsInner?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
siteName ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
title ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
type ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
url ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
videos ↔ List<MmOpenGraphVideosInner>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmOpenGraph?
Returns a new MmOpenGraph instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmOpenGraph>?
mapFromJson(dynamic json) → Map<String, MmOpenGraph>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmOpenGraph>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.