MmOpenGraphArticle class

Constructors

MmOpenGraphArticle({String? publishedTime, String? modifiedTime, String? expirationTime, String? section, List<String> tags = const [], List<MmOpenGraphArticleAuthorsInner> authors = const []})
Returns a new MmOpenGraphArticle instance.

Properties

authors ↔ List<MmOpenGraphArticleAuthorsInner>
getter/setter pair
expirationTime ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
modifiedTime ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
publishedTime ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
section ↔ String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
tags ↔ List<String>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmOpenGraphArticle?
Returns a new MmOpenGraphArticle instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmOpenGraphArticle>?
mapFromJson(dynamic json) → Map<String, MmOpenGraphArticle>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmOpenGraphArticle>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.