MmOpenInteractiveDialogRequest class

Constructors

MmOpenInteractiveDialogRequest({required String triggerId, required String url, required MmOpenInteractiveDialogRequestDialog dialog})
Returns a new MmOpenInteractiveDialogRequest instance.

Properties

dialog ↔ MmOpenInteractiveDialogRequestDialog
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggerId ↔ String
Trigger ID provided by other action
getter/setter pair
url ↔ String
The URL to send the submitted dialog payload to
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmOpenInteractiveDialogRequest?
Returns a new MmOpenInteractiveDialogRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmOpenInteractiveDialogRequest>?
mapFromJson(dynamic json) → Map<String, MmOpenInteractiveDialogRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmOpenInteractiveDialogRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.