MmOpenInteractiveDialogRequestDialog class

Constructors

MmOpenInteractiveDialogRequestDialog({String? callbackId, required String title, String? introductionText, List<Map> elements = const [], String? submitLabel, bool? notifyOnCancel, String? state})
Returns a new MmOpenInteractiveDialogRequestDialog instance.

Properties

callbackId ↔ String?
Set an ID that will be included when the dialog is submitted
getter/setter pair
elements ↔ List<Map>
Input elements, see https://docs.mattermost.com/developer/interactive-dialogs.html#elements
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
introductionText ↔ String?
Markdown formatted introductory paragraph
getter/setter pair
notifyOnCancel ↔ bool?
Set true to receive payloads when user cancels a dialog
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Set some state to be echoed back with the dialog submission
getter/setter pair
submitLabel ↔ String?
Label on the submit button
getter/setter pair
title ↔ String
Title of the dialog
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmOpenInteractiveDialogRequestDialog?
Returns a new MmOpenInteractiveDialogRequestDialog instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmOpenInteractiveDialogRequestDialog>?
mapFromJson(dynamic json) → Map<String, MmOpenInteractiveDialogRequestDialog>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmOpenInteractiveDialogRequestDialog>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.