MmOrderedSidebarCategories class

Constructors

MmOrderedSidebarCategories({List<String> order = const [], List<MmSidebarCategoryWithChannels> categories = const []})
Returns a new MmOrderedSidebarCategories instance.

Properties

categories ↔ List<MmSidebarCategoryWithChannels>
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
order ↔ List<String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmOrderedSidebarCategories?
Returns a new MmOrderedSidebarCategories instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmOrderedSidebarCategories>?
mapFromJson(dynamic json) → Map<String, MmOrderedSidebarCategories>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmOrderedSidebarCategories>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.