MmPatchRoleRequest class

Constructors

MmPatchRoleRequest({List<String> permissions = const []})
Returns a new MmPatchRoleRequest instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
permissions ↔ List<String>
The permissions the role should grant.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmPatchRoleRequest?
Returns a new MmPatchRoleRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmPatchRoleRequest>?
mapFromJson(dynamic json) → Map<String, MmPatchRoleRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmPatchRoleRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.