MmPluginManifest class

Constructors

MmPluginManifest({String? id, String? name, String? description, String? version, String? minServerVersion, MmPluginManifestBackend? backend, MmPluginManifestServer? server, MmPluginManifestWebapp? webapp, Map? settingsSchema})
Returns a new MmPluginManifest instance.

Properties

backend ↔ MmPluginManifestBackend?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
description ↔ String?
Description of what the plugin is and does.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
Globally unique identifier that represents the plugin.
getter/setter pair
minServerVersion ↔ String?
The minimum Mattermost server version required for the plugin. Available as server version 5.6.
getter/setter pair
name ↔ String?
Name of the plugin.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
server ↔ MmPluginManifestServer?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
settingsSchema ↔ Map?
Settings schema used to define the System Console UI for the plugin.
getter/setter pair
version ↔ String?
Version number of the plugin.
getter/setter pair
webapp ↔ MmPluginManifestWebapp?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmPluginManifest?
Returns a new MmPluginManifest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmPluginManifest>?
mapFromJson(dynamic json) → Map<String, MmPluginManifest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmPluginManifest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.