MmPostList class

Constructors

MmPostList({List<String> order = const [], Map<String, MmPost> posts = const {}, String? nextPostId, String? prevPostId, bool? hasNext})
Returns a new MmPostList instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
hasNext ↔ bool?
Whether there are more items after this page.
getter/setter pair
nextPostId ↔ String?
The ID of next post. Not omitted when empty or not relevant.
getter/setter pair
order ↔ List<String>
getter/setter pair
posts ↔ Map<String, MmPost>
getter/setter pair
prevPostId ↔ String?
The ID of previous post. Not omitted when empty or not relevant.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmPostList?
Returns a new MmPostList instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmPostList>?
mapFromJson(dynamic json) → Map<String, MmPostList>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmPostList>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.