MmPostListWithSearchMatches class

Constructors

MmPostListWithSearchMatches({List<String> order = const [], Map<String, MmPost> posts = const {}, Map<String, List<String>> matches = const {}})
Returns a new MmPostListWithSearchMatches instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
matches ↔ Map<String, List<String>>
A mapping of post IDs to a list of matched terms within the post. This field will only be populated on servers running version 5.1 or greater with Elasticsearch enabled.
getter/setter pair
order ↔ List<String>
getter/setter pair
posts ↔ Map<String, MmPost>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmPostListWithSearchMatches?
Returns a new MmPostListWithSearchMatches instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmPostListWithSearchMatches>?
mapFromJson(dynamic json) → Map<String, MmPostListWithSearchMatches>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmPostListWithSearchMatches>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.