MmReaction class

Constructors

MmReaction({String? userId, String? postId, String? emojiName, int? createAt})
Returns a new MmReaction instance.

Properties

createAt ↔ int?
The time in milliseconds this reaction was made
getter/setter pair
emojiName ↔ String?
The name of the emoji that was used for this reaction
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
postId ↔ String?
The ID of the post to which this reaction was made
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId ↔ String?
The ID of the user that made this reaction
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmReaction?
Returns a new MmReaction instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmReaction>?
mapFromJson(dynamic json) → Map<String, MmReaction>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmReaction>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.