MmRegisterTermsOfServiceActionRequest class

Constructors

MmRegisterTermsOfServiceActionRequest({required String serviceTermsId, required String accepted})
Returns a new MmRegisterTermsOfServiceActionRequest instance.

Properties

accepted ↔ String
true or false, indicates whether the user accepted or rejected the terms of service.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceTermsId ↔ String
terms of service ID on which the user is acting on
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmRegisterTermsOfServiceActionRequest?
Returns a new MmRegisterTermsOfServiceActionRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmRegisterTermsOfServiceActionRequest>?
mapFromJson(dynamic json) → Map<String, MmRegisterTermsOfServiceActionRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmRegisterTermsOfServiceActionRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.