MmRemoteClusterInfo class

Constructors

MmRemoteClusterInfo({String? displayName, int? createAt, int? lastPingAt})
Returns a new MmRemoteClusterInfo instance.

Properties

createAt ↔ int?
The time in milliseconds a remote cluster was created
getter/setter pair
displayName ↔ String?
The display name for the remote cluster
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
lastPingAt ↔ int?
The time in milliseconds a remote cluster was last pinged successfully
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmRemoteClusterInfo?
Returns a new MmRemoteClusterInfo instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmRemoteClusterInfo>?
mapFromJson(dynamic json) → Map<String, MmRemoteClusterInfo>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmRemoteClusterInfo>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.