MmRemoveRecentCustomStatusRequest class

Constructors

MmRemoveRecentCustomStatusRequest({required String emoji, required String text, required String duration, required String expiresAt})
Returns a new MmRemoveRecentCustomStatusRequest instance.

Properties

duration ↔ String
Duration of custom status, can be thirty_minutes, one_hour, four_hours, today, this_week or date_and_time
getter/setter pair
emoji ↔ String
Any emoji
getter/setter pair
expiresAt ↔ String
The time at which custom status should be expired. It should be in ISO format.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
Any custom status text
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmRemoveRecentCustomStatusRequest?
Returns a new MmRemoveRecentCustomStatusRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmRemoveRecentCustomStatusRequest>?
mapFromJson(dynamic json) → Map<String, MmRemoveRecentCustomStatusRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmRemoveRecentCustomStatusRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.