MmResetSamlAuthDataToEmailRequest class

Constructors

MmResetSamlAuthDataToEmailRequest({bool includeDeleted = false, bool dryRun = false, List<String> userIds = const []})
Returns a new MmResetSamlAuthDataToEmailRequest instance.

Properties

dryRun ↔ bool
If set to true, the number of users who would be affected is returned.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
includeDeleted ↔ bool
Whether to include deleted users.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userIds ↔ List<String>
If set to a non-empty array, then users whose IDs are not in the array will be excluded.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmResetSamlAuthDataToEmailRequest?
Returns a new MmResetSamlAuthDataToEmailRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmResetSamlAuthDataToEmailRequest>?
mapFromJson(dynamic json) → Map<String, MmResetSamlAuthDataToEmailRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmResetSamlAuthDataToEmailRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.