MmRetentionPolicyForChannelList class

Constructors

MmRetentionPolicyForChannelList({List<MmDataRetentionPolicyForChannel> policies = const [], int? totalCount})
Returns a new MmRetentionPolicyForChannelList instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
policies ↔ List<MmDataRetentionPolicyForChannel>
The list of channel policies.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCount ↔ int?
The total number of channel policies.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmRetentionPolicyForChannelList?
Returns a new MmRetentionPolicyForChannelList instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmRetentionPolicyForChannelList>?
mapFromJson(dynamic json) → Map<String, MmRetentionPolicyForChannelList>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmRetentionPolicyForChannelList>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.