MmRole class

Constructors

MmRole({String? id, String? name, String? displayName, String? description, List<String> permissions = const [], bool? schemeManaged})
Returns a new MmRole instance.

Properties

description ↔ String?
A human readable description of the role.
getter/setter pair
displayName ↔ String?
The human readable name for the role.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
The unique identifier of the role.
getter/setter pair
name ↔ String?
The unique name of the role, used when assigning roles to users/groups in contexts.
getter/setter pair
permissions ↔ List<String>
A list of the unique names of the permissions this role grants.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemeManaged ↔ bool?
indicates if this role is managed by a scheme (true), or is a custom stand-alone role (false).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmRole?
Returns a new MmRole instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmRole>?
mapFromJson(dynamic json) → Map<String, MmRole>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmRole>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.