MmScheme class

Constructors

MmScheme({String? id, String? name, String? description, int? createAt, int? updateAt, int? deleteAt, String? scope, String? defaultTeamAdminRole, String? defaultTeamUserRole, String? defaultChannelAdminRole, String? defaultChannelUserRole})
Returns a new MmScheme instance.

Properties

createAt ↔ int?
The time at which the scheme was created.
getter/setter pair
defaultChannelAdminRole ↔ String?
The id of the default channel admin role for this scheme.
getter/setter pair
defaultChannelUserRole ↔ String?
The id of the default channel user role for this scheme.
getter/setter pair
defaultTeamAdminRole ↔ String?
The id of the default team admin role for this scheme.
getter/setter pair
defaultTeamUserRole ↔ String?
The id of the default team user role for this scheme.
getter/setter pair
deleteAt ↔ int?
The time at which the scheme was deleted.
getter/setter pair
description ↔ String?
A human readable description of the scheme.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
The unique identifier of the scheme.
getter/setter pair
name ↔ String?
The human readable name for the scheme.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String?
The scope to which this scheme can be applied, either "team" or "channel".
getter/setter pair
updateAt ↔ int?
The time at which the scheme was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmScheme?
Returns a new MmScheme instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmScheme>?
mapFromJson(dynamic json) → Map<String, MmScheme>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmScheme>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.