MmSearchAllChannelsRequest class

Constructors

MmSearchAllChannelsRequest({required String term, String? notAssociatedToGroup, bool? excludeDefaultChannels, List<String> teamIds = const [], bool? groupConstrained, bool? excludeGroupConstrained, bool? public, bool? private, bool? deleted, String? page, String? perPage, bool excludePolicyConstrained = false})
Returns a new MmSearchAllChannelsRequest instance.

Properties

deleted ↔ bool?
Filters results to only return deleted / archived channels Minimum server version: 5.26
getter/setter pair
excludeDefaultChannels ↔ bool?
Exclude default channels from the results by setting this parameter to true.
getter/setter pair
excludeGroupConstrained ↔ bool?
Filters results to exclude channels constrained to a group Minimum server version: 5.26
getter/setter pair
excludePolicyConstrained ↔ bool
If set to true, only channels which do not have a granular retention policy assigned to them will be returned. The sysconsole_read_compliance_data_retention permission is required to use this parameter. Minimum server version: 5.35
getter/setter pair
groupConstrained ↔ bool?
Filters results to only return channels constrained to a group Minimum server version: 5.26
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
notAssociatedToGroup ↔ String?
A group id to exclude channels that are associated to that group via GroupChannel records.
getter/setter pair
page ↔ String?
The page number to return, if paginated. If this parameter is not present with the per_page parameter then the results will be returned un-paged.
getter/setter pair
perPage ↔ String?
The number of entries to return per page, if paginated. If this parameter is not present with the page parameter then the results will be returned un-paged.
getter/setter pair
private ↔ bool?
Filters results to only return Private channels, can be used in conjunction with public to return both private and public channels Minimum server version: 5.26
getter/setter pair
public ↔ bool?
Filters results to only return Public / Open channels, can be used in conjunction with private to return both public and private channels Minimum server version: 5.26
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teamIds ↔ List<String>
Filters results to channels belonging to the given team ids Minimum server version: 5.26
getter/setter pair
term ↔ String
The string to search in the channel name, display name, and purpose.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmSearchAllChannelsRequest?
Returns a new MmSearchAllChannelsRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmSearchAllChannelsRequest>?
mapFromJson(dynamic json) → Map<String, MmSearchAllChannelsRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmSearchAllChannelsRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.