MmSearchArchivedChannelsRequest class

Constructors

MmSearchArchivedChannelsRequest({required String term})
Returns a new MmSearchArchivedChannelsRequest instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
term ↔ String
The search term to match against the name or display name of archived channels
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmSearchArchivedChannelsRequest?
Returns a new MmSearchArchivedChannelsRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmSearchArchivedChannelsRequest>?
mapFromJson(dynamic json) → Map<String, MmSearchArchivedChannelsRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmSearchArchivedChannelsRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.