MmSearchChannelsForRetentionPolicyRequest class

Constructors

MmSearchChannelsForRetentionPolicyRequest({String? term, List<String> teamIds = const [], bool? public, bool? private, bool? deleted})
Returns a new MmSearchChannelsForRetentionPolicyRequest instance.

Properties

deleted ↔ bool?
Filters results to only return deleted / archived channels
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
private ↔ bool?
Filters results to only return Private channels, can be used in conjunction with public to return both private and public channels
getter/setter pair
public ↔ bool?
Filters results to only return Public / Open channels, can be used in conjunction with private to return both public and private channels
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teamIds ↔ List<String>
Filters results to channels belonging to the given team ids
getter/setter pair
term ↔ String?
The string to search in the channel name, display name, and purpose.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmSearchChannelsForRetentionPolicyRequest?
Returns a new MmSearchChannelsForRetentionPolicyRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmSearchChannelsForRetentionPolicyRequest>?
mapFromJson(dynamic json) → Map<String, MmSearchChannelsForRetentionPolicyRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmSearchChannelsForRetentionPolicyRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.