MmSearchEmojiRequest class

Constructors

MmSearchEmojiRequest({required String term, String? prefixOnly})
Returns a new MmSearchEmojiRequest instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
prefixOnly ↔ String?
Set to only search for names starting with the search term.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
term ↔ String
The term to match against the emoji name.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmSearchEmojiRequest?
Returns a new MmSearchEmojiRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmSearchEmojiRequest>?
mapFromJson(dynamic json) → Map<String, MmSearchEmojiRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmSearchEmojiRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.