MmSearchPostsRequest class

Constructors

MmSearchPostsRequest({required String terms, required bool isOrSearch, int timeZoneOffset = 0, bool? includeDeletedChannels, int page = 0, int perPage = 60})
Returns a new MmSearchPostsRequest instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
includeDeletedChannels ↔ bool?
Set to true if deleted channels should be included in the search. (archived channels)
getter/setter pair
isOrSearch ↔ bool
Set to true if an Or search should be performed vs an And search.
getter/setter pair
page ↔ int
The page to select. (Only works with Elasticsearch)
getter/setter pair
perPage ↔ int
The number of posts per page. (Only works with Elasticsearch)
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
terms ↔ String
The search terms as inputed by the user. To search for posts from a user include from:someusername, using a user's username. To search in a specific channel include in:somechannel, using the channel name (not the display name).
getter/setter pair
timeZoneOffset ↔ int
Offset from UTC of user timezone for date searches.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmSearchPostsRequest?
Returns a new MmSearchPostsRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmSearchPostsRequest>?
mapFromJson(dynamic json) → Map<String, MmSearchPostsRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmSearchPostsRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.