MmSearchUsersRequest class

Constructors

MmSearchUsersRequest({required String term, String? teamId, String? notInTeamId, String? inChannelId, String? notInChannelId, String? inGroupId, bool? groupConstrained, bool? allowInactive, bool? withoutTeam, int limit = 100})
Returns a new MmSearchUsersRequest instance.

Properties

allowInactive ↔ bool?
When true, include deactivated users in the results
getter/setter pair
groupConstrained ↔ bool?
When used with not_in_channel_id or not_in_team_id, returns only the users that are allowed to join the channel or team based on its group constrains.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
inChannelId ↔ String?
If provided, only search users in this channel
getter/setter pair
inGroupId ↔ String?
If provided, only search users in this group. Must have manage_system permission.
getter/setter pair
limit ↔ int
The maximum number of users to return in the results Available as of server version 5.6. Defaults to 100 if not provided or on an earlier server version.
getter/setter pair
notInChannelId ↔ String?
If provided, only search users not in this channel. Must specifiy team_id when using this option
getter/setter pair
notInTeamId ↔ String?
If provided, only search users not on this team
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teamId ↔ String?
If provided, only search users on this team
getter/setter pair
term ↔ String
The term to match against username, full name, nickname and email
getter/setter pair
withoutTeam ↔ bool?
Set this to true if you would like to search for users that are not on a team. This option takes precendence over team_id, in_channel_id, and not_in_channel_id.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmSearchUsersRequest?
Returns a new MmSearchUsersRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmSearchUsersRequest>?
mapFromJson(dynamic json) → Map<String, MmSearchUsersRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmSearchUsersRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.