MmServerBusy class

Constructors

MmServerBusy({bool? busy, int? expires})
Returns a new MmServerBusy instance.

Properties

busy ↔ bool?
True if the server is marked as busy (under high load)
getter/setter pair
expires ↔ int?
timestamp - number of seconds since Jan 1, 1970 UTC.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmServerBusy?
Returns a new MmServerBusy instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmServerBusy>?
mapFromJson(dynamic json) → Map<String, MmServerBusy>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmServerBusy>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.