MmSubmitInteractiveDialogRequest class

Constructors

MmSubmitInteractiveDialogRequest({required String url, required String channelId, required String teamId, required Map submission, String? callbackId, String? state, bool? cancelled})
Returns a new MmSubmitInteractiveDialogRequest instance.

Properties

callbackId ↔ String?
Callback ID sent when the dialog was opened
getter/setter pair
cancelled ↔ bool?
Set to true if the dialog was cancelled
getter/setter pair
channelId ↔ String
Channel ID the user submitted the dialog from
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State sent when the dialog was opened
getter/setter pair
submission ↔ Map
String map where keys are element names and values are the element input values
getter/setter pair
teamId ↔ String
Team ID the user submitted the dialog from
getter/setter pair
url ↔ String
The URL to send the submitted dialog payload to
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmSubmitInteractiveDialogRequest?
Returns a new MmSubmitInteractiveDialogRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmSubmitInteractiveDialogRequest>?
mapFromJson(dynamic json) → Map<String, MmSubmitInteractiveDialogRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmSubmitInteractiveDialogRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.