MmSwitchAccountType200Response class

Constructors

MmSwitchAccountType200Response({String? followLink})
Returns a new MmSwitchAccountType200Response instance.

Properties

The link for the user to follow to login or to complete the account switching when the current service is OAuth2/SAML
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmSwitchAccountType200Response?
Returns a new MmSwitchAccountType200Response instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmSwitchAccountType200Response>?
mapFromJson(dynamic json) → Map<String, MmSwitchAccountType200Response>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmSwitchAccountType200Response>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.