MmSystemStatusResponse class

Constructors

MmSystemStatusResponse({String? androidLatestVersion, String? androidMinVersion, String? desktopLatestVersion, String? desktopMinVersion, String? iosLatestVersion, String? iosMinVersion, String? databaseStatus, String? filestoreStatus, String? status, String? canReceiveNotifications})
Returns a new MmSystemStatusResponse instance.

Properties

androidLatestVersion ↔ String?
Latest Android version supported
getter/setter pair
androidMinVersion ↔ String?
Minimum Android version supported
getter/setter pair
canReceiveNotifications ↔ String?
Whether the device id provided can receive notifications ("true", "false" or "unknown"). Included when device_id parameter set.
getter/setter pair
databaseStatus ↔ String?
Status of database ("OK" or "UNHEALTHY"). Included when get_server_status parameter set.
getter/setter pair
desktopLatestVersion ↔ String?
Latest desktop version supported
getter/setter pair
desktopMinVersion ↔ String?
Minimum desktop version supported
getter/setter pair
filestoreStatus ↔ String?
Status of filestore ("OK" or "UNHEALTHY"). Included when get_server_status parameter set.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
iosLatestVersion ↔ String?
Latest iOS version supported
getter/setter pair
iosMinVersion ↔ String?
Minimum iOS version supported
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
Status of server ("OK" or "UNHEALTHY"). Included when get_server_status parameter set.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmSystemStatusResponse?
Returns a new MmSystemStatusResponse instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmSystemStatusResponse>?
mapFromJson(dynamic json) → Map<String, MmSystemStatusResponse>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmSystemStatusResponse>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.