MmTeamsLimits class

Constructors

MmTeamsLimits({int? active})
Returns a new MmTeamsLimits instance.

Properties

active ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmTeamsLimits?
Returns a new MmTeamsLimits instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmTeamsLimits>?
mapFromJson(dynamic json) → Map<String, MmTeamsLimits>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmTeamsLimits>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.