MmTermsOfService class

Constructors

MmTermsOfService({String? id, int? createAt, String? userId, String? text})
Returns a new MmTermsOfService instance.

Properties

createAt ↔ int?
The time at which the terms of service was created.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
The unique identifier of the terms of service.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
The text of terms of service. Supports Markdown.
getter/setter pair
userId ↔ String?
The unique identifier of the user who created these terms of service.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmTermsOfService?
Returns a new MmTermsOfService instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmTermsOfService>?
mapFromJson(dynamic json) → Map<String, MmTermsOfService>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmTermsOfService>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.