MmTestSiteURLRequest class

Constructors

MmTestSiteURLRequest({required String siteUrl})
Returns a new MmTestSiteURLRequest instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
siteUrl ↔ String
The Site URL to test
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmTestSiteURLRequest?
Returns a new MmTestSiteURLRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmTestSiteURLRequest>?
mapFromJson(dynamic json) → Map<String, MmTestSiteURLRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmTestSiteURLRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.