MmTimezone class

Constructors

MmTimezone({bool? useAutomaticTimezone, String? manualTimezone, String? automaticTimezone})
Returns a new MmTimezone instance.

Properties

automaticTimezone ↔ String?
This value is set automatically when the "useAutomaticTimezone" is set to "true".
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
manualTimezone ↔ String?
Value when setting manually the timezone, i.e. "Europe/Berlin".
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useAutomaticTimezone ↔ bool?
Set to "true" to use the browser/system timezone, "false" to set manually. Defaults to "true".
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmTimezone?
Returns a new MmTimezone instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmTimezone>?
mapFromJson(dynamic json) → Map<String, MmTimezone>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmTimezone>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.