MmTopChannelList class

Constructors

MmTopChannelList({bool? hasNext, List<MmTopChannel> items = const []})
Returns a new MmTopChannelList instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
hasNext ↔ bool?
Indicates if there is another page of channels that can be fetched.
getter/setter pair
items ↔ List<MmTopChannel>
List of channels.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmTopChannelList?
Returns a new MmTopChannelList instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmTopChannelList>?
mapFromJson(dynamic json) → Map<String, MmTopChannelList>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmTopChannelList>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.