MmUpdatePostRequest class

Constructors

MmUpdatePostRequest({required String id, bool? isPinned, String? message, bool? hasReactions, String? props})
Returns a new MmUpdatePostRequest instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
hasReactions ↔ bool?
Set to true if the post has reactions to it
getter/setter pair
id ↔ String
ID of the post to update
getter/setter pair
isPinned ↔ bool?
Set to true to pin the post to the channel it is in
getter/setter pair
message ↔ String?
The message text of the post
getter/setter pair
props ↔ String?
A general JSON property bag to attach to the post
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmUpdatePostRequest?
Returns a new MmUpdatePostRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmUpdatePostRequest>?
mapFromJson(dynamic json) → Map<String, MmUpdatePostRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmUpdatePostRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.