MmUpdateTeamRequest class

Constructors

MmUpdateTeamRequest({required String id, required String displayName, required String description, required String companyName, required String allowedDomains, required String inviteId, required String allowOpenInvite})
Returns a new MmUpdateTeamRequest instance.

Properties

allowedDomains ↔ String
getter/setter pair
allowOpenInvite ↔ String
getter/setter pair
companyName ↔ String
getter/setter pair
description ↔ String
getter/setter pair
displayName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String
getter/setter pair
inviteId ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmUpdateTeamRequest?
Returns a new MmUpdateTeamRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmUpdateTeamRequest>?
mapFromJson(dynamic json) → Map<String, MmUpdateTeamRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmUpdateTeamRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.