MmUpdateUserMfaRequest class

Constructors

MmUpdateUserMfaRequest({required bool activate, String? code})
Returns a new MmUpdateUserMfaRequest instance.

Properties

activate ↔ bool
Use true to activate, false to deactivate
getter/setter pair
code ↔ String?
The code produced by your MFA client. Required if activate is true
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmUpdateUserMfaRequest?
Returns a new MmUpdateUserMfaRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmUpdateUserMfaRequest>?
mapFromJson(dynamic json) → Map<String, MmUpdateUserMfaRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmUpdateUserMfaRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.