MmUpdateUserStatusRequest class

Constructors

MmUpdateUserStatusRequest({required String userId, required String status, int? dndEndTime})
Returns a new MmUpdateUserStatusRequest instance.

Properties

dndEndTime ↔ int?
Time in epoch seconds at which a dnd status would be unset.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String
User status, can be online, away, offline and dnd
getter/setter pair
userId ↔ String
User ID
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmUpdateUserStatusRequest?
Returns a new MmUpdateUserStatusRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmUpdateUserStatusRequest>?
mapFromJson(dynamic json) → Map<String, MmUpdateUserStatusRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmUpdateUserStatusRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.