MmUpgradeToEnterpriseStatus200Response class

Constructors

MmUpgradeToEnterpriseStatus200Response({int? percentage, String? error})
Returns a new MmUpgradeToEnterpriseStatus200Response instance.

Properties

error ↔ String?
Error happened during the upgrade
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
percentage ↔ int?
Current percentage of the upgrade
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmUpgradeToEnterpriseStatus200Response?
Returns a new MmUpgradeToEnterpriseStatus200Response instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmUpgradeToEnterpriseStatus200Response>?
mapFromJson(dynamic json) → Map<String, MmUpgradeToEnterpriseStatus200Response>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmUpgradeToEnterpriseStatus200Response>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.