MmUserAccessToken class

Constructors

MmUserAccessToken({String? id, String? token, String? userId, String? description})
Returns a new MmUserAccessToken instance.

Properties

description ↔ String?
A description of the token usage
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
Unique identifier for the token
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token ↔ String?
The token used for authentication
getter/setter pair
userId ↔ String?
The user the token authenticates for
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmUserAccessToken?
Returns a new MmUserAccessToken instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmUserAccessToken>?
mapFromJson(dynamic json) → Map<String, MmUserAccessToken>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmUserAccessToken>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.