MmUserAccessTokenSanitized class

Constructors

MmUserAccessTokenSanitized({String? id, String? userId, String? description, bool? isActive})
Returns a new MmUserAccessTokenSanitized instance.

Properties

description ↔ String?
A description of the token usage
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
Unique identifier for the token
getter/setter pair
isActive ↔ bool?
Indicates whether the token is active
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId ↔ String?
The user the token authenticates for
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmUserAccessTokenSanitized?
Returns a new MmUserAccessTokenSanitized instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmUserAccessTokenSanitized>?
mapFromJson(dynamic json) → Map<String, MmUserAccessTokenSanitized>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmUserAccessTokenSanitized>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.