MmUserNotifyProps class

Constructors

MmUserNotifyProps({bool? email, String? push, String? desktop, bool? desktopSound, String? mentionKeys, bool? channel, bool? firstName})
Returns a new MmUserNotifyProps instance.

Properties

channel ↔ bool?
Set to "true" to enable channel-wide notifications (@channel, @all, etc.), "false" to disable. Defaults to "true".
getter/setter pair
desktop ↔ String?
Set to "all" to receive desktop notifications for all activity, "mention" for mentions and direct messages only, and "none" to disable. Defaults to "all".
getter/setter pair
desktopSound ↔ bool?
Set to "true" to enable sound on desktop notifications, "false" to disable. Defaults to "true".
getter/setter pair
email ↔ bool?
Set to "true" to enable email notifications, "false" to disable. Defaults to "true".
getter/setter pair
firstName ↔ bool?
Set to "true" to enable mentions for first name. Defaults to "true" if a first name is set, "false" otherwise.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
mentionKeys ↔ String?
A comma-separated list of words to count as mentions. Defaults to username and @username.
getter/setter pair
push ↔ String?
Set to "all" to receive push notifications for all activity, "mention" for mentions and direct messages only, and "none" to disable. Defaults to "mention".
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmUserNotifyProps?
Returns a new MmUserNotifyProps instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmUserNotifyProps>?
mapFromJson(dynamic json) → Map<String, MmUserNotifyProps>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmUserNotifyProps>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.