MmVerifyUserEmailRequest class

Constructors

MmVerifyUserEmailRequest({required String token})
Returns a new MmVerifyUserEmailRequest instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token ↔ String
The token given to validate the email
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmVerifyUserEmailRequest?
Returns a new MmVerifyUserEmailRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmVerifyUserEmailRequest>?
mapFromJson(dynamic json) → Map<String, MmVerifyUserEmailRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmVerifyUserEmailRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.