MmViewChannel200Response class

Constructors

MmViewChannel200Response({String? status, Map? lastViewedAtTimes})
Returns a new MmViewChannel200Response instance.

Properties

hashCode → int
The hash code for this object.
no setteroverride
lastViewedAtTimes ↔ Map?
A JSON object mapping channel IDs to the channel view times
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
Value should be "OK" if successful
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmViewChannel200Response?
Returns a new MmViewChannel200Response instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmViewChannel200Response>?
mapFromJson(dynamic json) → Map<String, MmViewChannel200Response>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmViewChannel200Response>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.