MmViewChannelRequest class

Constructors

MmViewChannelRequest({required String channelId, String? prevChannelId})
Returns a new MmViewChannelRequest instance.

Properties

channelId ↔ String
The channel ID that is being viewed. Use a blank string to indicate that all channels have lost focus.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
prevChannelId ↔ String?
The channel ID of the previous channel, used when switching channels. Providing this ID will cause push notifications to clear on the channel being switched to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(dynamic value) → MmViewChannelRequest?
Returns a new MmViewChannelRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) → List<MmViewChannelRequest>?
mapFromJson(dynamic json) → Map<String, MmViewChannelRequest>
mapListFromJson(dynamic json, {bool growable = false}) → Map<String, List<MmViewChannelRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.