MmWsEvent class

Mattermost Websocket event message Documentation is here: https://api.mattermost.com/#tag/WebSocket

Inheritance
Implementers

Constructors

MmWsEvent()
MmWsEvent.fromJson(Map<String, dynamic> map)

Properties

broadcast ↔ Map<String, dynamic>
getter/setter pair
data ↔ Map<String, dynamic>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deeplyEncode() → Map<String, dynamic>
will encode the data back into the exact same format as sent here from mattermost.
fromJson(Map<String, dynamic> map) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

deeplyEncoded ↔ List<String>
getter/setter pair