MmWsEventHello class

Inheritance

Constructors

MmWsEventHello()
MmWsEventHello.fromJson(Map<String, dynamic> map)

Properties

bcData → Map<String, dynamic>
no setter
broadcast ↔ Map<String, dynamic>
getter/setter pairinherited
connectionId → String
no setter
data ↔ Map<String, dynamic>
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isDirect → bool
no setter
name ↔ String
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverVersion → String
no setter
userId → String
no setter

Methods

deeplyEncode() → Map<String, dynamic>
will encode the data back into the exact same format as sent here from mattermost.
inherited
fromJson(Map<String, dynamic> map) → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited