MmWsReply class

Mattermost websocket reply messages come as replies to websocket action requests

Inheritance

Constructors

MmWsReply(MmWsActionResponseStatus status, int? seqReply, {Map<String, String>? error, Map<String, dynamic>? data})
MmWsReply.fromJson(Map<String, dynamic> map)
factory
MmWsReply.noReply()
MmWsReply.unknown()

Properties

data ↔ Map<String, dynamic>?
getter/setter pair
error ↔ Map<String, String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isError → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seqReply ↔ int?
getter/setter pair
status ↔ MmWsActionResponseStatus
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited